/**
 * Request parameter generator
 * @internal
 * @packageDocumentation
 */
/**
 * Parsed data returned from Geometry Dash requests
 */
export declare type GDRequestData = {
    [k: string]: string | number;
};
/**
 * Parameters for Geometry Dash requests
 */
export default class GDRequestParams {
    private data;
    /**
     * Creates a new group of Geometry Dash request parameters.
     * @param data The key-value pairs to insert
     */
    constructor(data?: GDRequestData);
    /**
     * Inserts new parameters into the request parameter list.
     * @param data The key-value pairs to insert
     * @returns The new raw data
     */
    insertParams(data: GDRequestData): GDRequestData;
    /**
     * Authorizes the parameters for a certain type of request.
     * @param type The type of request to authenticate for
     * @returns The new raw data
     */
    authorize(type?: keyof typeof SECRETS): GDRequestData;
    /**
     * Resolves the request parameters to a URLSearchParams object.
     * @returns The parameters as a URLSearchParams object
     */
    resolve(): URLSearchParams;
}
